import os
import g4s

USERNAME: str = os.environ["g4s_username"]
PASSWORD: str = os.environ["g4s_password"]


def test_creation():
    alarm = g4s.Alarm(USERNAME, PASSWORD)
    assert alarm is not None



from enum import Enum
from typing import Any


class ArmType(Enum):
    FULL_ARM = 0
    NIGHT_ARM = 1
    UNKNOWN = 2
    DISARMED = 3

    def __str__(self) -> str:
        return self.name

    def __repr__(self) -> str:
        return str(self)


class DeviceType(Enum):
    UNKNOWN = -1
    HUB = 1
    DOORWINDOWSENSOR = 2
    PANEL = 14
    SMOKEALARM = 16
    SIREN = 24
    CAMERA = 38
    ZWAVECONTROLLER = 116
    ACCESSCHIP = 201

    @classmethod
    def _missing_(cls, value: Any):
        return DeviceType.UNKNOWN

    def __str__(self) -> str:
        return self.name

    def __repr__(self) -> str:
        return str(self)


class EventType(Enum):
    UNKNOWN = -1
    ARM = 39
    DISARM = 40
    NIGHTARM = 57

    @classmethod
    def _missing_(cls, value: Any):
        return EventType.UNKNOWN

    def __str__(self) -> str:
        return self.name

    def __repr__(self) -> str:
        return str(self)



from typing import Any, Dict
from g4s.utils.panel_state import PanelState
from g4s.utils.panel_settings import PanelSettings
from g4s.utils.state_device import StateDevice
from g4s.utils.user import User
from g4s.utils.api import API


class AlarmStatus:
    def __init__(self, input_dict: Dict[str, Any], api: API) -> None:
        self.panel_id: int = input_dict["panelInfo"]["PanelId"]
        self.name: str = input_dict["panelInfo"]["Name"]
        self.panel_settings: PanelSettings = PanelSettings(input_dict["panelSettings"])
        self.panel_state: PanelState = PanelState(input_dict["panelState"], self.panel_settings.time_zone)
        self.state_devices: list[StateDevice] = [
            StateDevice(device, self.panel_settings.time_zone) for device in input_dict["stateDevices"]
        ]
        self.system_state: PanelState = PanelState(input_dict["systemState"], self.panel_settings.time_zone)
        self.users: list[User] = [User(user, api, self.panel_settings.time_zone) for user in input_dict["users"]]
